@@ -63,7 +63,7 @@ CREATE TABLE `goip` (
   `gsm_status` VARCHAR(30) not NULL,
   `voip_status` VARCHAR(30) not NULL,
   `voip_state` VARCHAR(30) not NULL,
-  `bal` FLOAT(11) default '-1',
+  `bal` FLOAT default '-1',
   `CELLINFO` varchar(160) NOT NULL,
   `CGATT` varchar(32) NOT NULL,
   `BCCH` varchar(160) NOT NULL,
@@ -562,7 +562,7 @@ CREATE TABLE IF NOT EXISTS `auto_ussd` (
   `crontime` int(11) NOT NULL,
   `bal_sms_r` varchar(160) character set utf8 NOT NULL,
   `bal_ussd_r` varchar(160) character set utf8 NOT NULL,
-  `bal_limit` int(11) NOT NULL,
+  `bal_limit` float NOT NULL,
   `recharge_ussd` varchar(160) character set utf8 NOT NULL,
   `last_time` timestamp NOT NULL default '0000-00-00 00:00:00',
   `next_time` int(10) unsigned NOT NULL default '0',
