@@ -357,5 +357,10 @@ ADD  `auto_ussd_step4` VARCHAR( 160 ) CHARACTER SET utf8 COLLATE utf8_general_ci
 ADD  `auto_ussd_step4_start_r` VARCHAR( 160 ) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL ;");
 
 	@$db->updatequery("ALTER TABLE  `receive` ADD  `smscnum` VARCHAR( 32 ) NOT NULL ;");
+
+/*1.22.1 add doapi*/
+
+/*1.22.1 changed bal_limit to float*/
+	@$db->updatequery("ALTER TABLE  `auto_ussd` CHANGE  `bal_limit`  `bal_limit` FLOAT NOT NULL");
 	echo "update done! <a href=''  target=_top>Return</a>";
 ?>
